use std::env::current_dir;

use once_cell::sync::OnceCell;
use redb::Database;
use tauri::api::path::config_dir;

use crate::picker;

trait GlobalDatabase<T> {
    fn global() -> &'static T;
}

impl GlobalDatabase<Database> for Database {
    fn global() -> &'static Database {
        static GLOBAL_DATABASE: OnceCell<Database> = OnceCell::new();

        GLOBAL_DATABASE.get_or_init(|| {
            let path = config_dir()
                .unwrap_or(current_dir().unwrap())
                .join("main.redb");
            let db = Database::create(path).unwrap();
            return db;
        })
    }
}
