import { isNil } from 'ramda';
import { FC, Fragment, useMemo } from 'react';
import tw, { css, styled } from 'twin.macro';
import { useLedCount } from '../contents/led-count';
import { PixelRgb } from '../models/pixel-rgb';
import { StyledPixel } from './styled-pixel';
import { BorderLedStrip } from './completed-led-strip';

const StyledCompletedContainerBorder = styled.section(
  tw`dark:shadow-xl border-gray-600 bg-black border rounded-full flex flex-nowrap justify-around items-center p-px h-3 mb-1`,
  css`
    grid-column: 1 / -1;
    grid-row: 1 / span 1;
    justify-self: stretch;
  `,
);
interface StyledCompletedContainerProps {
  borderLedStrips: BorderLedStrip[];
  overrideBorderLedStrips?: BorderLedStrip[];
}
export const CompletedContainer: FC<StyledCompletedContainerProps> = ({
  borderLedStrips,
  overrideBorderLedStrips,
}) => {
  const { ledCount } = useLedCount();
  const completedPixels = useMemo(() => {
    const completed: PixelRgb[] = new Array(ledCount).fill([0, 0, 0]);
    (overrideBorderLedStrips ?? borderLedStrips).forEach(({ pixels, config }) => {
      if (isNil(config)) {
        return;
      }
      if (config.global_start_position <= config.global_end_position) {
        pixels.forEach((color, i) => {
          completed[config.global_start_position + i] = color;
        });
      } else {
        pixels.forEach((color, i) => {
          completed[config.global_start_position - i] = color;
        });
      }
    });

    return completed.map((color, i) => (
      <StyledPixel
        rgb={color}
        key={i}
        css={css`
          grid-row-start: 1;
          grid-column-start: ${i + 1};
          align-self: flex-start;
        `}
      />
    ));
  }, [ledCount, borderLedStrips, overrideBorderLedStrips]);

  return (
    <Fragment>
      <StyledCompletedContainerBorder />
      {completedPixels}
    </Fragment>
  );
};
