import { HTMLAttributes, useMemo } from 'react';
import { FC } from 'react';
import { LedStripConfig } from '../models/led-strip-config';
import tw, { css, styled } from 'twin.macro';
import { splitEvery } from 'ramda';
import { StyledPixel } from './styled-pixel';

export interface LedStripProps extends HTMLAttributes<HTMLElement> {
  config: LedStripConfig | null;
  colors: Uint8Array;
}

const StyledContainer = styled.section(
  tw`dark:bg-transparent shadow-xl border-gray-500 border rounded-full flex flex-wrap justify-around items-center -mx-px -mt-px`,
  css``,
);

export const LedStrip: FC<LedStripProps> = ({ config, colors, ...htmlAttrs }) => {
  const pixels = useMemo(() => {
    const pixels = splitEvery(3, Array.from(colors)) as Array<[number, number, number]>;
    return pixels.map((rgb, index) => <StyledPixel key={index} rgb={rgb}></StyledPixel>);
  }, [colors]);
  return (
    <StyledContainer {...htmlAttrs} css={[!config && tw`bg-gray-200`]}>
      {pixels}
    </StyledContainer>
  );
};
